pub struct CFHost { /* private fields */ }CFHost only.Expand description
Implementations
Sourceimpl CFHost
impl CFHost
pub unsafe fn with_name( allocator: Option<&CFAllocator>, hostname: &CFString, ) -> CFRetained<CFHost>
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn with_address( allocator: Option<&CFAllocator>, addr: &CFData, ) -> CFRetained<CFHost>
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn new_copy( alloc: Option<&CFAllocator>, host: &CFHost, ) -> CFRetained<CFHost>
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Sourcepub unsafe fn start_info_resolution(
&self,
info: CFHostInfoType,
error: *mut CFStreamError,
) -> bool
👎Deprecated: Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn start_info_resolution( &self, info: CFHostInfoType, error: *mut CFStreamError, ) -> bool
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Safety
error must be a valid pointer or null.
Sourcepub unsafe fn addressing(
&self,
has_been_resolved: *mut u8,
) -> Option<CFRetained<CFArray>>
👎Deprecated: Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn addressing( &self, has_been_resolved: *mut u8, ) -> Option<CFRetained<CFArray>>
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Safety
has_been_resolved must be a valid pointer or null.
Sourcepub unsafe fn names(
&self,
has_been_resolved: *mut u8,
) -> Option<CFRetained<CFArray>>
👎Deprecated: Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn names( &self, has_been_resolved: *mut u8, ) -> Option<CFRetained<CFArray>>
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Safety
has_been_resolved must be a valid pointer or null.
Sourcepub unsafe fn reachability(
&self,
has_been_resolved: *mut u8,
) -> Option<CFRetained<CFData>>
👎Deprecated: Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn reachability( &self, has_been_resolved: *mut u8, ) -> Option<CFRetained<CFData>>
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Safety
has_been_resolved must be a valid pointer or null.
pub unsafe fn cancel_info_resolution(&self, info: CFHostInfoType)
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Sourcepub unsafe fn set_client(
&self,
client_cb: CFHostClientCallBack,
client_context: *mut CFHostClientContext,
) -> bool
👎Deprecated: Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn set_client( &self, client_cb: CFHostClientCallBack, client_context: *mut CFHostClientContext, ) -> bool
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Safety
client_cbmust be implemented correctly.client_contextmust be a valid pointer or null.
Sourcepub unsafe fn schedule_with_run_loop(
&self,
run_loop: &CFRunLoop,
run_loop_mode: &CFString,
)
👎Deprecated: Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn schedule_with_run_loop( &self, run_loop: &CFRunLoop, run_loop_mode: &CFString, )
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Safety
run_loop possibly has additional threading requirements.
Sourcepub unsafe fn unschedule_from_run_loop(
&self,
run_loop: &CFRunLoop,
run_loop_mode: &CFString,
)
👎Deprecated: Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
pub unsafe fn unschedule_from_run_loop( &self, run_loop: &CFRunLoop, run_loop_mode: &CFString, )
Use Network framework instead, see deprecation notice in <CFNetwork/CFHost.h>
Safety
run_loop possibly has additional threading requirements.
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.