pub struct CFNetServiceMonitor { /* private fields */ }CFNetServices only.Expand description
Implementations
Sourceimpl CFNetServiceMonitor
impl CFNetServiceMonitor
Sourcepub unsafe fn new(
alloc: Option<&CFAllocator>,
the_service: &CFNetService,
client_cb: CFNetServiceMonitorClientCallBack,
client_context: NonNull<CFNetServiceClientContext>,
) -> CFRetained<CFNetServiceMonitor>
👎Deprecated: Use nw_browser_t or nw_listener_t in Network framework instead
pub unsafe fn new( alloc: Option<&CFAllocator>, the_service: &CFNetService, client_cb: CFNetServiceMonitorClientCallBack, client_context: NonNull<CFNetServiceClientContext>, ) -> CFRetained<CFNetServiceMonitor>
Use nw_browser_t or nw_listener_t in Network framework instead
Safety
client_cbmust be implemented correctly.client_contextmust be a valid pointer.
pub unsafe fn invalidate(&self)
Use nw_browser_t or nw_listener_t in Network framework instead
Sourcepub unsafe fn start(
&self,
record_type: CFNetServiceMonitorType,
error: *mut CFStreamError,
) -> bool
👎Deprecated: Use nw_browser_t or nw_listener_t in Network framework instead
pub unsafe fn start( &self, record_type: CFNetServiceMonitorType, error: *mut CFStreamError, ) -> bool
Use nw_browser_t or nw_listener_t in Network framework instead
Safety
error must be a valid pointer or null.
Sourcepub unsafe fn stop(&self, error: *mut CFStreamError)
👎Deprecated: Use nw_browser_t or nw_listener_t in Network framework instead
pub unsafe fn stop(&self, error: *mut CFStreamError)
Use nw_browser_t or nw_listener_t in Network framework instead
Safety
error must be a valid pointer or null.
Sourcepub unsafe fn schedule_with_run_loop(
&self,
run_loop: &CFRunLoop,
run_loop_mode: &CFString,
)
👎Deprecated: Use nw_browser_t or nw_listener_t in Network framework instead
pub unsafe fn schedule_with_run_loop( &self, run_loop: &CFRunLoop, run_loop_mode: &CFString, )
Use nw_browser_t or nw_listener_t in Network framework instead
Safety
run_loop possibly has additional threading requirements.
Sourcepub unsafe fn unschedule_from_run_loop(
&self,
run_loop: &CFRunLoop,
run_loop_mode: &CFString,
)
👎Deprecated: Use nw_browser_t or nw_listener_t in Network framework instead
pub unsafe fn unschedule_from_run_loop( &self, run_loop: &CFRunLoop, run_loop_mode: &CFString, )
Use nw_browser_t or nw_listener_t in Network framework instead
Safety
run_loop possibly has additional threading requirements.
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.